@@ -4,8 +4,8 @@
 
 ;; Author: Alexandr Timchenko
 ;; URL: https://github.com/tmythicator/ob-ts-node
-;; Package-Version: 0.4
-;; Package-Revision: a480e19fc204
+;; Package-Version: 20250929.1013
+;; Package-Revision: 11e25ba2f73b
 ;; Keywords: languages, tools
 ;; Package-Requires: ((emacs "25.1") (org "8.0"))
 
@@ -44,7 +44,6 @@
 ;; - Execution of `#+begin_src typescript` and `#+begin_src ts` blocks
 ;; - Automatic tangling to `.ts` files
 ;;
-;;
 
 ;;; Code:
 (require 'ob)
@@ -58,11 +57,14 @@
 (defcustom ob-ts-node-tsconfig nil
   "Path to a tsconfig.json used by ob-ts-node by default.
 Highly recommended to set for stable, reproducible behavior (see ts-node docs)."
-  :type '(choice (const :tag "Disabled" nil) (string :tag "Path"))
+  :type '(choice (const :tag "Disabled" nil)
+                 (string :tag "Path"))
   :group 'org-babel)
 
 (defvar org-babel-default-header-args:typescript
-  '((:cli-args . nil) (:cli-override . nil) (:cli-cmd . nil))
+  '((:cli-args    . nil)
+    (:cli-override . nil)
+    (:cli-cmd . nil))
   "Default header arguments for TypeScript Babel blocks.
 
 Recognized keys:
@@ -77,29 +79,18 @@ Recognized keys:
   "Execute BODY as TypeScript code using ts-node with PARAMS."
   (let* ((src (org-babel-temp-file "ts-" ".ts"))
          (args (alist-get :cli-args params))
-         (override (alist-get :cli-override params))
-         (skip-project-p
-          (and args (string-match-p "--skip-project" args)))
-         (use-project-p
-          (and ob-ts-node-tsconfig (not skip-project-p)))
-         (cmd-base
-          (if use-project-p
-              (format "%s --project %s"
-                      ob-ts-node-command
-                      ob-ts-node-tsconfig)
-            ob-ts-node-command))
+         (ovr (alist-get :cli-override params))
+         (cmd-base (if ob-ts-node-tsconfig
+                       (concat ob-ts-node-command " --project " ob-ts-node-tsconfig)
+                     ob-ts-node-command))
          (cmd (or (alist-get :cli-cmd params) cmd-base))
          (file (org-babel-process-file-name src)))
-    (with-temp-file src
-      (insert body))
+    (with-temp-file src (insert body))
     (let ((command
            (cond
-            (override
-             (format "%s %s" cmd override))
-            (args
-             (format "%s %s %s" cmd args file))
-            (t
-             (format "%s %s" cmd file)))))
+            (ovr  (format "%s %s" cmd ovr))
+            (args (format "%s %s %s" cmd args file))
+            (t    (format "%s %s"    cmd file)))))
       (org-babel-eval command ""))))
 
 ;;;###autoload
@@ -121,16 +112,12 @@ Argument PARAMS is an alist of header arguments controlling execution."
   "Register TypeScript support for Org Babel and src editing."
   (add-to-list 'org-babel-tangle-lang-exts '("typescript" . "ts"))
   (add-to-list 'org-babel-tangle-lang-exts '("ts" . "ts"))
-  (let ((mode
-         (cond
-          ((fboundp 'typescript-ts-mode)
-           'typescript-ts)
-          ((fboundp 'typescript-mode)
-           'typescript)
-          (t
-           'js))))
+  (let ((mode (cond
+               ((fboundp 'typescript-ts-mode) 'typescript-ts)
+               ((fboundp 'typescript-mode)    'typescript)
+               (t 'js))))
     (dolist (lang '("typescript" "ts"))
       (add-to-list 'org-src-lang-modes (cons lang mode)))))
 
 (provide 'ob-ts-node)
-;;; ob-ts-node.el ends here
+;;; ob-ts-node.el ends here
\ No newline at end of file
